Clazz.declarePackage("JS");
Clazz.load(["JS.LayoutManager"], "JS.BorderLayout", null, function(){
var c$ = Clazz.declareType(JS, "BorderLayout", JS.LayoutManager);
});
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
